"""sdk functions"""


def change_led():
    """function for change LED """
    response = "lead change"
    print(response)
    return response


def buzzer_beep():
    """function for Buzzer beep"""
    response = "buzzer beep"
    print(response)
    return response


def get_media():
    """function for get media"""
    response = "get media"
    print(response)
    return response
